//-----------------------------------------------------------------------------
// Title      : bsp_ub054_mk3_wav1
//-----------------------------------------------------------------------------
// Funktion   : WAV-Files abspielen und Daten anzeigen
// Schaltung  : myAVR MK3
//-----------------------------------------------------------------------------
// Prozessor  : ATMega2560
// Takt       : 16 MHz
// Sprache    : C
// Date       : 14.07.2012
// Version    : 1.0
// Autor      : UB
//-----------------------------------------------------------------------------
#define F_CPU 16000000
#include <avr/io.h>
#include <ub_mk3_2560/MK3_2560_LCD.h>
#include <ub_mk3_2560/MK3_2560_KEY.h>
#include <ub_mk3_2560/MK3_2560_WAV.h>

//-----------------------------------------------------------------------------
// Hinweis : Quick-Jumper Port-C+A und Port-K muss gesetzt sein
// - WAV File muss auf der SD-Karte vorhanden sein
// - Lautsprecher muss an Port B7 angeschlossen sein
// - oeffnet ein WAV-File und zeigt den WAV-Header
//   auf dem Display an
// - Button 1=START, 2=PAUSE, 3=STOP
//-----------------------------------------------------------------------------

#define WAV_NAME "m8k8b.wav"  // mono, 8khz, 8bit


//-----------------------------------------
void showHeader(void) {
  unsigned int uint;
  
  uint=WAV_HEADER.fmt_tag;
  MK3_LCD_STRING_AT(0,24,"TYP=");
  MK3_LCD_PRINT_UTYP(uint,HEX_U2);
  
  uint=WAV_HEADER.kanal;
  MK3_LCD_STRING_AT(60,24,"CH=");
  MK3_LCD_PRINT_UTYP(uint,HEX_U2); 
  
  uint=WAV_HEADER.sampl;
  MK3_LCD_STRING_AT(0,32,"FRQ=");
  MK3_LCD_PRINT_UTYP(uint,DEZ_U5);
  
  uint=WAV_HEADER.frame;
  MK3_LCD_STRING_AT(60,32,"Frame=");
  MK3_LCD_PRINT_UTYP(uint,HEX_U2);

  uint=WAV_HEADER.bits;
  MK3_LCD_STRING_AT(0,40,"Bits=");
  MK3_LCD_PRINT_UTYP(uint,DEZ_U2);
  
  uint=(WAV_HEADER.len>>16);
  MK3_LCD_STRING_AT(0,48,"Len [hex]=");
  MK3_LCD_PRINT_UTYP(uint,HEX_U4);
  uint=(WAV_HEADER.len&0x0000FFFF);
  MK3_LCD_PRINT_UTYP(uint,HEX_U4);

  
}

//-----------------------------------------
void loadWAV(void) {
  WAV_CHK check;

  check=MK3_WAV_LOAD(WAV_NAME);
  if(check==WAV_LOAD_OK) {
    MK3_LCD_STRING_AT(0,16,"WAV File OK");
  }
  else if(check==WAV_NO_SD) {
    MK3_LCD_STRING_AT(0,16,"keine SD-Karte");
  }
  else if(check==WAV_FILE_NOT_FOUND) {
    MK3_LCD_STRING_AT(0,16,"File not found");
  }
  else if(check==WAV_HEADER_ERR) {
    MK3_LCD_STRING_AT(0,16,"WAV-Header err=");
    // fehlernummer anzeigen
    MK3_LCD_PRINT_UTYP(WAV_HEADER.err_nr,DEZ_U2);
  }  
  else {
    MK3_LCD_STRING_AT(0,16,"Error");
  }  
  
  // Daten der WAV anzeigen
  if((check==WAV_LOAD_OK) || (check==WAV_HEADER_ERR)) {
    showHeader();
  }
}

int main (void)
{

	
	MK3_INIT_LCD();					// init des LCD
	MK3_INIT_KEY();                 // init der Tasten
	MK3_INIT_WAV();                 // init der WAV-Ausgabe
	
	MK3_LCD_CLEAR();				// LCD loeschen
	MK3_LCD_LIGHT(true);			// beleuchtung einschalten
	
	MK3_LCD_STRING_AT(0,0,"File:");
	MK3_LCD_PRINT_STRING(WAV_NAME);
	MK3_LCD_STRING_AT(0,8,"suche WAV-File");
	
    loadWAV();
	

	while (true)
	{
	  MK3_WAV_DO();
	  
      if(MK3_KEY_SET(BUTTON1)==true) {
        MK3_LCD_STRING_AT(0,56,"START");
        MK3_WAV_START(WAV_NAME);
      }
      if(MK3_KEY_SET(BUTTON2)==true) {
        MK3_LCD_STRING_AT(0,56,"PAUSE");
        MK3_WAV_PAUSE();
      }
      if(MK3_KEY_SET(BUTTON3)==true) {
        MK3_LCD_STRING_AT(0,56,"STOP ");
        MK3_WAV_STOP();
      }	
	}
	return 0;
}
//-----------------------------------------------------------------------------






